@@ -12,6 +12,7 @@ config = {
         "MYSQL_PASSWORD": "{{ 8|random_string }}",
         "SECRET_KEY": "{{ 20|random_string }}",
         "OAUTH2_SECRET": "{{ 8|random_string }}",
+        "OAUTH2_SECRET_SSO": "{{ 8|random_string }}",
         "API_KEY": "{{ 20|random_string }}",
         "PAYMENT_PROCESSORS": {
             "cybersource": {
@@ -22,7 +23,7 @@ config = {
                 "transaction_key": "SET-ME-PLEASE",
                 "payment_page_url": "https://testsecureacceptance.cybersource.com/pay",
                 "receipt_page_url": "/checkout/receipt/",
-                "cancel_page_url": "/checkout/cancel-checkout/",
+                "cancel_checkout_path": "/checkout/cancel-checkout/",
                 "soap_api_url": "https://ics2wstest.ic3.com/commerce/1.x/transactionProcessor/CyberSourceTransaction_1.140.wsdl",
                 "send_level_2_3_details": True,
                 "sop_profile_id": "SET-ME-PLEASE",
@@ -51,8 +52,11 @@ config = {
         "MYSQL_DATABASE": "ecommerce",
         "MYSQL_USERNAME": "ecommerce",
         "OAUTH2_KEY": "ecommerce",
+        "OAUTH2_KEY_DEV": "ecommerce-dev",
+        "OAUTH2_KEY_SSO": "ecommerce-sso",
+        "OAUTH2_KEY_SSO_DEV": "ecommerce-sso-dev",
         "API_TIMEOUT": 5,
-        "WORKER_JWT_ISSUER": "ecommerce-worker",
+        "WORKER_JWT_ISSUER": "ecommerce-worker",# TODO do we need to keep this?
         "EXTRA_PIP_REQUIREMENTS": [],
     },
 }
